@@ -25,10 +25,12 @@
 """
 
 from . import doc
-from . import PyScanFCS
+from . import main
+from . import uilayer
+from . import SFCSnumeric
 
 ## VERSION
 version = doc.__version__
 __version__ = version
 
-PyScanFCS.Main()
+main.Main()
